<?php
if ( !is_admin() ) {
  add_filter( 'query_vars', 'dw_date_pagination_query_var' );
  function dw_date_pagination_query_var( $query_vars ) {
    $query_vars[] = 'date_pagination_type';
    return $query_vars;
  }
  add_action( 'pre_get_posts', 'dw_date_pagination_pre_get_posts', 99 );
  function dw_date_pagination_pre_get_posts( $query ) {
    $type = $query->get( 'date_pagination_type' );
    
    if ( is_date() || !dw_date_pagination_is_valid_type( $type ) ) {
      return;
    }
    $reset_query_vars =  array(
      'second' , 'minute', 'hour',
      'day', 'monthnum', 'year',
      'w', 'm',
    );
    foreach ( $reset_query_vars as $var ) {
      $query->set( $var, '' );
    }
    $query->set( 'nopaging', true );
  }
add_filter( 'posts_clauses', 'dw_date_pagination_posts_clauses', 99, 2 );
function dw_date_pagination_posts_clauses( $clauses, $query ) {
  global $wpdb;
  $type = $query->get( 'date_pagination_type' );
    
  if ( is_date() || !dw_date_pagination_is_valid_type( $type ) ) {
    return $clauses;
  }
  $select = "YEAR($wpdb->posts.post_date) AS `year`";
  $groupby = "YEAR($wpdb->posts.post_date)";
  if ( $type == 'monthly' || $type == 'daily' ) {
    $select .= ", MONTH($wpdb->posts.post_date) AS `month`";
    $groupby .= ", MONTH($wpdb->posts.post_date)";
  }
  if ( $type == 'daily' ) {
    $select .= ", DAYOFMONTH($wpdb->posts.post_date) AS `dayofmonth`";
    $groupby .= ", DAYOFMONTH($wpdb->posts.post_date)";
  }
  $date_query = "SELECT $select, count($wpdb->posts.ID) as posts FROM $wpdb->posts " . $clauses['join'] . " WHERE 1=1". $clauses['where'] ." GROUP BY $groupby ORDER BY " . $clauses['orderby'];
  $dates = $wpdb->get_results( $date_query );
  if ( $dates ) {
    $page_count = count( $dates );
    $query->set( 'date_pagination_max_num_pages', $page_count );
    add_filter( 'the_posts', 'dw_date_pagination_max_num_pages', 99, 2 );
    if ( get_query_var( 'paged' ) ) { 
      $paged = get_query_var( 'paged' ); 
    } elseif ( get_query_var( 'page' ) ) { 
      $paged = get_query_var( 'page' ); 
    } else { 
      $paged = 1; 
    }
    if ( $paged > $page_count ) {
      $clauses['where'] .= " AND 1=0";
    }
    $start = (int) $paged-1;
    $date = array_slice( (array) $dates, $start, 1 );
    $query->set( 'date_pagination_current', $date );
    $next = array_slice( (array) $dates, $start+1, 1 );
    $query->set( 'date_pagination_next', $next );
    if ( $start > 0 ) {
      $prev = array_slice( (array) $dates, $start-1, 1 );
      $query->set( 'date_pagination_prev', $prev );
    } else {
      $query->set( 'date_pagination_prev', array() );
    }
    if ( $date ) {
      $clauses['limits'] = '';
      if ( isset( $date[0]->year ) ) {
        $clauses['where'] .= " AND YEAR($wpdb->posts.post_date)='" . $date[0]->year . "'";
      }
      if ( isset( $date[0]->month ) ) {
        $clauses['where'] .= " AND MONTH($wpdb->posts.post_date)='" . $date[0]->month . "'";
      }
      if ( isset( $date[0]->dayofmonth ) ) {
        $clauses['where'] .= " AND DAYOFMONTH($wpdb->posts.post_date)='" . $date[0]->dayofmonth . "'";
      }
    }
  }
  return $clauses;
}

function dw_date_pagination_max_num_pages( $posts, $query ) {
  $max_num_pages = $query->get( 'date_pagination_max_num_pages' );
  if ( !empty( $max_num_pages ) ) {
    $query->max_num_pages = $max_num_pages;
  }
  return $posts;
}

function dw_date_pagination_is_valid_type( $type ) {
  if ( in_array( (string) $type, array( 'yearly', 'monthly', 'daily' ) ) ) {
    return true;
  }
  return false;
}

function dw_get_next_date_label( $format = '', $query = 0  ) {
  return dw_date_pagination_get_date( $format, $query );
}

function dw_get_previous_date_label( $format = '', $query = 0 ) {
  return dw_date_pagination_get_date( $format, $query, true );
}

function dw_get_current_date_label( $format = '', $query = 0 ) {
  return dw_date_pagination_get_date( $format, $query, 'current' );
}

function dw_date_pagination_get_date( $format = '', $query = 0, $previous = 0 ) {
  $date = '';
  if ( is_date() ) {
    return $date;
  }
  if ( !$query ) {
    global $wp_query;
    $query = $wp_query;
  }
  if ( !is_a( (object) $query, 'WP_Query' ) ) {
    return $date;
  }
  $type = $query->get( 'date_pagination_type' );
  if ( !empty( $type ) && dw_date_pagination_is_valid_type( $type ) ) {
    $next_prev = 'date_pagination_next';
    if ( $previous ) {
      $next_prev = 'date_pagination_prev';
      if ( $previous === 'current' ) {
        $next_prev = 'date_pagination_current';
      }
    }
    $date_obj = $query->get( $next_prev );
    if ( !empty( $date_obj ) ) {
      $year = ( isset( $date_obj[0]->year ) ) ? absint( $date_obj[0]->year ): 0;
      $month = ( isset( $date_obj[0]->month ) ) ? absint( $date_obj[0]->month ): 0;
      $day = ( isset( $date_obj[0]->dayofmonth ) ) ? absint( $date_obj[0]->dayofmonth ): 0;
      if ( ( $type == 'yearly' ) && $year ) {
        $date = $year . '-01-01';
        $format = ( '' != $format ) ? (string) $format : 'Y';
      }
      if ( ( $type == 'monthly' ) && $year && $month ) {
        $date = $year . '-' . zeroise( $month, 2 ) . '-01';
        $format = ( '' != $format ) ? (string) $format : 'F Y';
      }
      if ( ( $type == 'daily' )  && $year && $month && $day ) {
        $date = $year . '-' . zeroise( $month, 2 ) . zeroise( $day, 2 );
        $format = ( '' != $format ) ? (string) $format : ' F j, Y';
      }
    }
  }
  return ( '' != $date ) ? mysql2date( $format, $date . ' 00:00:00' ) : '';
}
}
function dw_time_line_date_query( $term_id = null, $type = null , $order_date = 'DESC') {
  global $wpdb;
  if ( isset( $term_id ) ) {
    if ( 'term' == $type ) {
      $result = $wpdb->get_results("
                  SELECT p1.post_date
                  From
                      $wpdb->posts p1 
                  INNER JOIN
                      $wpdb->term_relationships p2
                  WHERE
                      p2.term_taxonomy_id = '{$term_id}' AND
                      p2.object_id = p1.ID AND
                      p1.post_type = 'post' AND
                      p1.post_status = 'publish' 
                  ORDER by 
                      p1.post_date $order_date
      ") ;
    } else if ( 'author' == $type ) {
      $result = $wpdb->get_results("
                    SELECT p1.post_date
                    From
                        $wpdb->posts p1 
                    WHERE
                        p1.post_author = '{$term_id}' AND
                        p1.post_type = 'post' AND
                        p1.post_status = 'publish' 
                    ORDER by 
                        p1.post_date $order_date
        ") ;
    }
  } else {
    $result = $wpdb->get_results("
              SELECT p1.post_date
              FROM  $wpdb->posts p1
              WHERE p1.post_status = 'publish' AND
                    p1.post_type = 'post'
              ORDER BY 
                    post_date $order_date
              ");
  }
  return $result;
}
function dw_timeline_get_date_array( $term_id = null, $type = null , $order_date='DESC') {
  $result = dw_time_line_date_query( $term_id, $type , $order_date);
  $date_array = array();
  foreach ( $result as $r ) {
      $date = substr( $r->post_date, 0 , 7 );
 
    if ( ! in_array( $date , $date_array ) ) {
      $date_array[] = $date;
    }
  }
  return $date_array;
}

function dw_time_line_pro_modify_main_query( $query ) {
  $page_options = get_option('dw_timeline_theme_options');
  $page_options['dw_timeline_main_pagination_enable'] = isset( $page_options['dw_timeline_main_pagination_enable'] ) ? $page_options['dw_timeline_main_pagination_enable'] : 'no';
  if ( 'yes' == $page_options['dw_timeline_main_pagination_enable'] ) {
    if ( is_home() || is_archive() && $query->is_main_query() ) {
        $query->query_vars['date_pagination_type'] = 'monthly';
		
		$date_order = !empty( $page_options['dw_timeline_main_orderby'] ) ? $page_options['dw_timeline_main_orderby'] : 'DESC';
		$query->query_vars['order'] = $date_order;
      }
    } else {
    return;
  }
}
add_action( 'pre_get_posts', 'dw_time_line_pro_modify_main_query' );

function dw_time_line_pro_pagination( $pages, $date_array ) {
  for ( $i=1 ; $i <= $pages; $i++) {
    $j = $i-1;
      $str2t = strtotime( $date_array[$j] );
      $date = date_i18n( 'F' , $str2t );
    $class = 'data-page';
    if ( 1 == $i ) {
     if ( isset( $date_array[0] ) ) {
       echo '<ul class="open"><li class="pager-year" data-year="'.substr( $date_array[0], 0 , 4 ).'">'.substr( $date_array[0], 0 , 4 ).'</li>';
      }
    }
    
    if ( isset( $date_array[$j] ) ) {
     echo '<li class="'. $class .'" data-page="'. $i .'" data-year="'.substr( $date_array[$j], 0 , 4 ).'" ><a href="#" >'. esc_attr( $date ) .'</a></li>';
    }
    if( isset( $date_array[$i] ) && isset( $date_array[$j] ) ) {
      if ( substr( $date_array[$j], 0, 4 ) != substr( $date_array[$i], 0 , 4 )  ) {
        echo '</ul><ul><li class="pager-year" data-year="'.substr( $date_array[$i], 0 , 4 ).'">'.substr( $date_array[$i], 0 , 4 ).'</li>';
      }
    }
    if ( $pages == $i ) {
      echo '</ul>';
    }


  }
}